@@ -105,11 +105,11 @@ impl AWSCluster {
         }
     }
 
-    pub fn bastion(self) -> Self {
+    pub fn bastion(self, enabled: bool) -> Self {
         Self {
             spec: AWSClusterSpec {
                 bastion: Some(Bastion {
-                    enabled: Some(true),
+                    enabled: Some(enabled),
                     allowed_cidr_blocks: vec!["0.0.0.0/0".to_string()],
                     ..Bastion::default()
                 }),
